[X2Go-Commits] python-x2go.git - build-baikal (branch) updated: 0.0.44.2-34-g908efcb

X2Go dev team git-admin at x2go.org
Wed Jan 8 15:30:26 CET 2014


The branch, build-baikal has been updated
       via  908efcb0ac21ac6243ea04599174287100014ae7 (commit)
      from  78a551576d2d1a0f7119176d8b49ec1b2495d7de (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
-----------------------------------------------------------------------

Summary of changes:
 x2go/cache.py |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

The diff of changes is:
diff --git a/x2go/cache.py b/x2go/cache.py
index 14b2833..45f2e9b 100644
--- a/x2go/cache.py
+++ b/x2go/cache.py
@@ -43,7 +43,7 @@ class X2goListSessionsCache(object):
     in the session list cache.
 
     Whenever your client application needs access to the server's session list,
     the list sessions cache is queried instead. This assures that the server's
     session list is available without delay, even on slow internet connections.
 
     """
@@ -73,7 +73,7 @@ class X2goListSessionsCache(object):
 
     def delete(self, profile_name):
         """\
-        Remove session list for a given profile.
+        Remove session list from cache for a given profile.
 
         @param profile_name: name of profile to operate on
         @type profile_name: C{str}
@@ -84,9 +84,9 @@ class X2goListSessionsCache(object):
 
     def check_cache(self):
         """\
         Check if list sessions cache elements are still valid (i.e. if the corresponding
         session profile is still connected). If not so, remove invalid cache entries from
-        the list sessions cache.
+        the session list cache.
 
         """
         for profile_name in self.x2go_listsessions_cache.keys():
@@ -43,7 +43,7 @@ class X2goListSessionsCache(object):
 
     Whenever your client application needs access to the server's session list,
-    the list sessions cache is queried instead. This assures that the server's
+    the session list cache is queried instead. This assures that the server's
     session list is available without delay, even on slow internet connections.
 
@@ -84,9 +84,9 @@ class X2goListSessionsCache(object):
     def check_cache(self):
         """\
-        Check if list sessions cache elements are still valid (i.e. if the corresponding
+        Check if session list cache elements are still valid (i.e. if the corresponding
         session profile is still connected). If not so, remove invalid cache entries from


hooks/post-receive
-- 
python-x2go.git (Python X2Go Client API)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "python-x2go.git" (Python X2Go Client API).




More information about the x2go-commits mailing list